// 游戏状态枚举
export enum GameStatus {
    PREPARING = 'preparing', // 准备中
    ONGOING = 'ongoing',     // 进行中
    SOLVED = 'solved',       // 已解决
    EXPIRED = 'expired'      // 已过期
}
  
// 问题模型
export interface Question {
    id: string;            // 问题ID
    playerId: string;      // 提问玩家ID
    playerName: string;    // 提问玩家名称
    content: string;       // 问题内容
    answer?: string;       // 回答 (是/否/不相关)
    createdAt: Date;       // 创建时间
    answeredAt?: Date;     // 回答时间
}
  
// 基础游戏模型
export interface BaseGame {
    id: string;            // 游戏ID
    roomId: string;        // 关联房间ID
    type: string;          // 游戏类型
    title: string;         // 标题
    startTime: Date;       // 开始时间
    endTime?: Date;        // 结束时间
    status: GameStatus;    // 游戏状态
}
  
// 海龟汤游戏模型
export interface TurtleSoupGame extends BaseGame {
    initialStory: string;  // 初始故事
    hints: string[];       // 提示列表
    solution: string;      // 解答
    revealedHints: number[]; // 已公开提示索引
    questions: Question[]; // 问题列表
}
  
// 游戏结果模型
export interface GameResult {
    gameId: string;
    solved: boolean;
    solvedBy?: string;
    solvedAt?: Date;
    duration: number;      // 游戏持续时间（秒）
    questionsCount: number;
    hintsRevealed: number;
}
  
// 游戏配置选项
export interface GameOptions {
    gameType: string;
    difficulty: string;
    timeLimit?: number;
    customSettings?: Record<string, any>;
}